<?php
/**
 * An interface for responses
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright(c) 2007, 2008 Roland Haeder, this is free software
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
interface Responseable extends FrameworkInterface {
	/**
	 * Setter for status
	 *
	 * @param	$status		New response status
	 * @return	void
	 */
	function setResponseStatus ($status);

	/**
	 * Add header element
	 *
	 * @param	$name	Name of header element
	 * @param	$value	Value of header element
	 * @return	void
	 */
	function addHeader ($name, $value);

	/**
	 * "Writes" data to the response body
	 *
	 * @param	$output		Output we shall sent in the HTTP response
	 * @return	void
	 */
	function writeToBody ($output);

	/**
	 * Flushs the cached HTTP response to the outer world
	 *
	 * @param	$foce	Wether we shall force the output or abort if headers are
	 *					already sent with an exception
	 * @return	void
	 * @throws	ResponseHeadersAlreadySentException		Thrown if headers are
	 *													already sent
	 */
	function flushBuffer($force=false);

	/**
	 * Adds a fatal message id to the response. The added messages can then be
	 * processed and outputed to the world
	 *
	 * @param	$messageId	The message id we shall add
	 * @return	void
	 */
	function addFatalMessage ($messageId);
}

//
?>
